@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : TNG
-Version : 1.0.12
+Version : 1.0.15
 Author  : Stefano Covino
-Date    : 22/04/2013
+Date    : 25/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -27,9 +27,12 @@ History : (29/02/2012) First version.
         : (08/04/2013) V. 0.3.0b2.
         : (09/04/2013) V. 0.3.0b3.
         : (22/04/2013) V. 0.3.0.
+        : (24/07/2013) V. 0.3.1b1.
+        : (21/08/2013) V. 0.4.0b1.
+        : (25/08/2013) V. 0.4.0.
 """
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 
 __all__ =  ['GetObj', 'GetTNGSite'] 
